# Verhaltenskodex für Mitwirkende

## Unser Versprechen

Wir als Mitglieder, Mitwirkende und Führungskräfte verpflichten uns, die Teilnahme an unserer  
Gemeinschaft zu einer belästigungsfreien Erfahrung für alle zu machen, unabhängig von Alter, Körpergröße,  
sichtbarer oder unsichtbarer Behinderung, ethnischer Zugehörigkeit, Geschlechtsmerkmalen, Geschlechtsidentität  
und -ausdruck, Erfahrungsniveau, Bildung, sozioökonomischem Status, Nationalität, persönlichem Aussehen,  
Rasse, Religion oder sexueller Identität und Orientierung.  

Wir verpflichten uns, auf eine Weise zu handeln und zu interagieren, die zu einer offenen, einladenden,  
vielfältigen, inklusiven und gesunden Gemeinschaft beiträgt.

## Unsere Standards

Beispiele für Verhaltensweisen, die zu einer positiven Umgebung für unsere Gemeinschaft beitragen, sind:

* Empathie und Freundlichkeit gegenüber anderen Menschen zeigen
* Respekt vor unterschiedlichen Meinungen, Ansichten und Erfahrungen haben
* Konstruktives Feedback geben und es annehmen
* Verantwortung übernehmen und sich bei den Betroffenen für unsere Fehler entschuldigen und aus den Erfahrungen lernen
* Sich nicht nur auf das konzentrieren, was für uns als Einzelne am besten ist, sondern auf die gesamte Gemeinschaft

Beispiele für inakzeptables Verhalten sind:

* Die Verwendung sexualisierter Sprache oder Bilder sowie sexuelle Aufmerksamkeit oder Annäherungsversuche jeglicher Art  
* Trollen, beleidigende oder abfällige Kommentare sowie persönliche oder politische Angriffe  
* Belästigung in der Öffentlichkeit oder im Privaten  
* Das Veröffentlichen privater Informationen anderer, wie einer physischen oder E-Mail-Adresse, ohne deren ausdrückliche Erlaubnis  
* Anderes Verhalten, das vernünftigerweise als unangemessen in einem professionellen Umfeld angesehen werden könnte

## Durchsetzungsverantwortung

Gemeinschaftsleiter sind dafür verantwortlich, unsere Standards für akzeptables Verhalten zu klären und durchzusetzen. Sie werden angemessene und faire Korrekturmaßnahmen ergreifen, um auf jedes Verhalten zu reagieren, das sie als unangemessen, bedrohlich, beleidigend oder schädlich erachten.

Gemeinschaftsleiter haben das Recht und die Verantwortung, Kommentare, Commits, Code, Wiki-Bearbeitungen, Issues und andere Beiträge zu entfernen, zu bearbeiten oder abzulehnen, die nicht mit diesem Verhaltenskodex übereinstimmen. Sie werden die Gründe für Moderationsentscheidungen kommunizieren, wenn dies angemessen ist.

## Anwendungsbereich

Dieser Verhaltenskodex gilt in allen Gemeinschaftsräumen und gilt auch, wenn  
eine Person die Gemeinschaft offiziell in öffentlichen Räumen vertritt.  
Beispiele für die Vertretung unserer Gemeinschaft sind die Verwendung einer offiziellen E-Mail-Adresse,  
das Posten über ein offizielles Social-Media-Konto oder die Tätigkeit als ernannter  
Vertreter bei einer Online- oder Offline-Veranstaltung.

## Durchsetzung

Fälle von missbräuchlichem, belästigendem oder anderweitig inakzeptablem Verhalten können den für die Durchsetzung verantwortlichen Gemeinschaftsleitern unter aw@funstory.ai gemeldet werden.  
Alle Beschwerden werden umgehend und fair überprüft und untersucht.  

Alle Gemeinschaftsleiter sind verpflichtet, die Privatsphäre und Sicherheit des Meldenden eines Vorfalls zu respektieren.

## Durchsetzungsrichtlinien

Gemeinschaftsleiter werden diese Richtlinien zur Gemeinschaftsauswirkung befolgen, um die Konsequenzen für jede Handlung zu bestimmen, die sie als Verstoß gegen diesen Verhaltenskodex erachten:

### 1. Korrektur

**Gemeinschaftsauswirkung**: Verwendung unangemessener Sprache oder anderer Verhaltensweisen, die in der Gemeinschaft als unprofessionell oder unerwünscht angesehen werden.

**Konsequenz**: Eine private, schriftliche Warnung von Gemeinschaftsleitern, die Klarheit über die Art des Verstoßes und eine Erklärung dafür bietet, warum das Verhalten unangemessen war. Eine öffentliche Entschuldigung kann verlangt werden.

### 2. Warnung

**Auswirkungen auf die Gemeinschaft**: Eine Verletzung durch einen einzelnen Vorfall oder eine Reihe von Handlungen.

**Konsequenz**: Eine Warnung mit Konsequenzen für fortgesetztes Verhalten. Keine Interaktion mit den beteiligten Personen, einschließlich unaufgeforderter Interaktion mit denen, die den Verhaltenskodex durchsetzen, für einen bestimmten Zeitraum. Dies beinhaltet die Vermeidung von Interaktionen in Gemeinschaftsräumen sowie in externen Kanälen wie sozialen Medien. Die Verletzung dieser Bedingungen kann zu einem temporären oder dauerhaften Verbot führen.

### 3. Temporäres Verbot

**Auswirkungen auf die Gemeinschaft**: Eine schwerwiegende Verletzung der Gemeinschaftsstandards, einschließlich anhaltend unangemessenen Verhaltens.

**Konsequenz**: Ein temporäres Verbot jeglicher Art von Interaktion oder öffentlicher Kommunikation mit der Gemeinschaft für einen bestimmten Zeitraum. Während dieses Zeitraums sind keine öffentlichen oder privaten Interaktionen mit den beteiligten Personen erlaubt, einschließlich unaufgeforderter Interaktionen mit denen, die den Verhaltenskodex durchsetzen. Die Verletzung dieser Bedingungen kann zu einer dauerhaften Sperre führen.

### 4. Dauerhafte Sperre

**Auswirkungen auf die Gemeinschaft**: Aufzeigen eines Musters der Verletzung von Gemeinschaftsstandards, einschließlich anhaltend unangemessenen Verhaltens, Belästigung einer Einzelperson oder Aggression gegenüber oder Herabsetzung von Gruppen von Personen.

**Konsequenz**: Eine dauerhafte Sperre für jegliche Art der öffentlichen Interaktion innerhalb der Gemeinschaft.

## Zuschreibung

Dieser Verhaltenskodex ist angepasst vom [Contributor Covenant][homepage],  
Version 2.0, verfügbar unter  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.  

Die Community Impact Guidelines wurden inspiriert von [Mozillas Code of Conduct  
Enforcement Ladder](https://github.com/mozilla/diversity).  

[homepage]: https://www.contributor-covenant.org  

Antworten auf häufig gestellte Fragen zu diesem Verhaltenskodex finden Sie in den FAQ unter  
https://www.contributor-covenant.org/faq. Übersetzungen sind verfügbar unter  
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Ein Teil des Inhalts dieser Seite wurde von GPT übersetzt und kann Fehler enthalten.</small></h6>